Gensim – Python Framework for Vector Space Modelling — gensim documentation

### Navigation

- index
- modules |
- next |
- Gensim home|
- API reference|
- Tutorials »

# Gensim – Python Framework for Vector Space Modelling

What’s new in version 0.7?

- faster and leaner Latent Semantic Indexing (LSI) and Latent Dirichlet Allocation (LDA):
  - Processing the English Wikipedia, 3.2 million documents (NIPS workshop paper)
  - Distributed Latent Semantic Analysis & Distributed Latent Dirichlet Allocation
- Input corpus iterators can come from a compressed file (bzip2, gzip, ...), to save disk space when dealing with very large corpora.
- gensim code now resides on github.

For an overview of what you can (or cannot) do with gensim, go to the introduction.

For installation and troubleshooting, see the installation page and the gensim discussion group.

For examples on how to use it, try the tutorials.

When citing gensim in academic papers, please use this BibTeX entry.

## Quick Reference Example

    >>> from gensim import corpora, models, similarities
    >>>
    >>> # load corpus iterator from a Matrix Market file on disk
    >>> corpus = corpora.MmCorpus('/path/to/corpus.mm')
    >>>
    >>> # initialize a transformation (Latent Semantic Indexing with 200 latent dimensions)
    >>> lsi = models.LsiModel(corpus, numTopics=200)
    >>>
    >>> # convert another corpus to the latent space and index it
    >>> index = similarities.MatrixSimilarity(lsi[another_corpus])
    >>>
    >>> # perform similarity query of a query in LSI space against the whole corpus
    >>> sims = index[query]

### Navigation

- index
- modules |
- next |
- Gensim home|
- API reference|
- Tutorials »